import type { Node } from "../graph/node.js";
import { Edge } from "../graph/edge.js";
import { Graph } from "../graph/graph.js";
import { GraphLayout } from "./graph-layout.js";
export type GraphEngineProps = {
    graph: Graph;
    layout: GraphLayout;
};
/** Graph engine controls the graph data and layout calculation */
export declare class GraphEngine extends EventTarget {
    props: Readonly<Required<GraphEngineProps>>;
    private readonly _graph;
    private readonly _layout;
    private readonly _cache;
    private _layoutDirty;
    private _transactionInProgress;
    constructor(props: GraphEngineProps);
    /** @deprecated Use props constructor: new GraphEngine(props) */
    constructor(graph: Graph, layout: GraphLayout);
    /** Getters */
    getNodes: () => Node[];
    getEdges: () => Edge[];
    getNodePosition: (node: Node) => [number, number];
    getEdgePosition: (edge: Edge) => {
        type: string;
        sourcePosition: number[];
        targetPosition: number[];
        controlPoints: any[];
    };
    getGraphVersion: () => number;
    getLayoutLastUpdate: () => number;
    getLayoutState: () => import("./graph-layout").GraphLayoutState;
    /** Operations on the graph */
    lockNodePosition: (node: any, x: any, y: any) => void;
    unlockNodePosition: (node: any) => void;
    /**
     * @fires GraphEngine#onLayoutStart
     */
    _onLayoutStart: () => void;
    /**
     * @fires GraphEngine#onLayoutChange
     */
    _onLayoutChange: () => void;
    /**
     * @fires GraphEngine#onLayoutDone
     */
    _onLayoutDone: () => void;
    /**
     * @fires GraphEngine#onLayoutError
     */
    _onLayoutError: () => void;
    _onGraphStructureChanged: (entity: any) => void;
    _onTransactionStart: () => void;
    _onTransactionEnd: () => void;
    /** Layout calculations */
    run: () => void;
    clear: () => void;
    resume: () => void;
    stop: () => void;
    _graphChanged: () => void;
    _updateLayout: () => void;
    _updateCache(key: any, updateValue: any): void;
}
//# sourceMappingURL=graph-engine.d.ts.map